@@ -9,6 +9,7 @@ use crate::{
 use serde::Deserialize;
 use serde_json::{json, Value};
 use std::{collections::HashMap, time::Duration};
+use time::OffsetDateTime;
 
 /// The top-level struct of the SDK, representing a client containing [indexes](../indexes/struct.Index.html).
 #[derive(Debug, Clone)]
@@ -175,7 +176,7 @@ impl Client {
         uid: impl AsRef<str>,
         primary_key: Option<&str>,
     ) -> Result<Task, Error> {
-        Ok(request::<Value, Task>(
+        request::<Value, Task>(
             &format!("{}/indexes", self.host),
             &self.api_key,
             Method::Post(json!({
@@ -184,19 +185,19 @@ impl Client {
             })),
             202,
         )
-        .await?)
+        .await
     }
 
     /// Delete an index from its UID.
     /// To delete an [Index], use the [Index::delete] method.
     pub async fn delete_index(&self, uid: impl AsRef<str>) -> Result<Task, Error> {
-        Ok(request::<(), Task>(
+        request::<(), Task>(
             &format!("{}/indexes/{}", self.host, uid.as_ref()),
             &self.api_key,
             Method::Delete,
             202,
         )
-        .await?)
+        .await
     }
 
     /// Alias for [Client::list_all_indexes].
@@ -466,7 +467,7 @@ impl Client {
     /// # Example
     ///
     /// ```
-    /// # use meilisearch_sdk::{client::*, document, indexes::*, tasks::Task};
+    /// # use meilisearch_sdk::{client::*, indexes::*, tasks::Task};
     /// # use serde::{Serialize, Deserialize};
     /// #
     /// # #[derive(Debug, Serialize, Deserialize, PartialEq)]
@@ -476,13 +477,6 @@ impl Client {
     /// #    kind: String,
     /// # }
     /// #
-    /// # impl document::Document for Document {
-    /// #    type UIDType = usize;
-    /// #
-    /// #    fn get_uid(&self) -> &Self::UIDType {
-    /// #        &self.id
-    /// #    }
-    /// # }
     /// #
     /// # futures::executor::block_on(async move {
     /// let client = Client::new("http://localhost:7700", "masterKey");
@@ -582,13 +576,32 @@ impl Client {
 
         Ok(tasks.results)
     }
+
+    /// Generates a new tenant token.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// # use meilisearch_sdk::*;
+    /// # futures::executor::block_on(async move {
+    /// # let client = client::Client::new("http://localhost:7700", "masterKey");
+    /// let token = client.generate_tenant_token(serde_json::json!(["*"]), None, None).unwrap();
+    /// let client = client::Client::new("http://localhost:7700", token);
+    /// # });
+    /// ```
+    pub fn generate_tenant_token(&self, search_rules: serde_json::Value, api_key: Option<&str>, expires_at: Option<OffsetDateTime>) -> Result<String, Error> {
+        let api_key = api_key.unwrap_or(&self.api_key);
+
+        crate::tenant_tokens::generate_tenant_token(search_rules, api_key, expires_at)
+    }
 }
 
 #[derive(Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct ClientStats {
     pub database_size: usize,
-    pub last_update: Option<String>,
+    #[serde(with = "time::serde::rfc3339::option")]
+    pub last_update: Option<OffsetDateTime>,
     pub indexes: HashMap<String, IndexStats>,
 }
 
@@ -878,6 +891,41 @@ mod tests {
         Ok(())
     }
 
+    #[meilisearch_test]
+    async fn test_error_create_index(client: Client, index: Index) -> Result<(), Error> {
+        let error = client
+            .create_index("Wrong index name", None)
+            .await
+            .unwrap_err();
+
+        assert!(matches!(
+            error,
+            Error::Meilisearch(MeilisearchError {
+                error_code: ErrorCode::InvalidIndexUid,
+                error_type: ErrorType::InvalidRequest,
+                ..
+            })
+        ));
+
+        // we try to create an index with the same uid of an already existing index
+        let error = client
+            .create_index(&*index.uid, None)
+            .await?
+            .wait_for_completion(&client, None, None)
+            .await?
+            .unwrap_failure();
+
+        assert!(matches!(
+            error,
+            MeilisearchError {
+                error_code: ErrorCode::IndexAlreadyExists,
+                error_type: ErrorType::InvalidRequest,
+                ..
+            }
+        ));
+        Ok(())
+    }
+
     #[meilisearch_test]
     async fn test_list_all_indexes(client: Client, index: Index) {
         let all_indexes = client.list_all_indexes().await.unwrap();
