@@ -280,10 +280,10 @@ impl<'a> Query<'a> {
 
 #[cfg(test)]
 mod tests {
-    use crate::{client::*, document, search::*};
+    use crate::{client::*, search::*};
     use meilisearch_test_macro::meilisearch_test;
     use serde::{Deserialize, Serialize};
-    use serde_json::{Map, Value};
+    use serde_json::{Map, Value, json};
 
     #[derive(Debug, Serialize, Deserialize, PartialEq)]
     struct Document {
@@ -292,14 +292,6 @@ mod tests {
         kind: String,
     }
 
-    impl document::Document for Document {
-        type UIDType = usize;
-
-        fn get_uid(&self) -> &Self::UIDType {
-            &self.id
-        }
-    }
-
     impl PartialEq<Map<String, Value>> for Document {
         fn eq(&self, rhs: &Map<String, Value>) -> bool {
             self.id.to_string() == rhs["id"]
@@ -579,4 +571,39 @@ mod tests {
         assert_eq!(results.hits.len(), 1);
         Ok(())
     }
+
+    #[meilisearch_test]
+    async fn test_generate_tenant_token_from_client(client: Client, index: Index) -> Result<(), Error> {
+        use crate::key::{KeyBuilder, Action};
+
+        setup_test_index(&client, &index).await?;
+
+        let key = KeyBuilder::new("key for generate_tenant_token test")
+            .with_action(Action::All)
+            .with_index("*")
+            .create(&client).await.unwrap();
+        let allowed_client = Client::new("http://localhost:7700", key.key);
+
+        let search_rules = vec![
+            json!({ "*": {}}),
+            json!({ "*": Value::Null }),
+            json!(["*"]),
+            json!({ "*": { "filter": "kind = text" } }),
+            json!([index.uid.to_string()]),
+        ];
+
+        for rules in search_rules {
+            let token = allowed_client.generate_tenant_token(rules, None, None).expect("Cannot generate tenant token.");
+            let new_client = Client::new("http://localhost:7700", token);
+
+            let result: SearchResults<Document> = new_client.index(index.uid.to_string())
+                .search()
+                .execute()
+                .await?;
+
+            assert!(!result.hits.is_empty());
+        }
+
+        Ok(())
+    }
 }
