@@ -15,6 +15,7 @@ pub enum TaskType {
     DocumentPartial { details: Option<DocumentAddition> },
     DocumentDeletion { details: Option<DocumentDeletion> },
     IndexCreation { details: Option<IndexCreation> },
+    IndexUpdate { details: Option<IndexUpdate> },
     IndexDeletion { details: Option<IndexDeletion> },
     SettingsUpdate { details: Option<Settings> },
 }
@@ -38,6 +39,12 @@ pub struct IndexCreation {
     pub primary_key: Option<String>,
 }
 
+#[derive(Debug, Clone, Deserialize)]
+#[serde(rename_all = "camelCase")]
+pub struct IndexUpdate {
+    pub primary_key: Option<String>,
+}
+
 #[derive(Debug, Clone, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct IndexDeletion {
@@ -149,7 +156,7 @@ impl Task {
     /// # Example
     ///
     /// ```
-    /// # use meilisearch_sdk::{client::*, document, indexes::*, tasks::Task};
+    /// # use meilisearch_sdk::{client::*, indexes::*, tasks::Task};
     /// # use serde::{Serialize, Deserialize};
     /// #
     /// # #[derive(Debug, Serialize, Deserialize, PartialEq)]
@@ -159,13 +166,6 @@ impl Task {
     /// #    kind: String,
     /// # }
     /// #
-    /// # impl document::Document for Document {
-    /// #    type UIDType = usize;
-    /// #
-    /// #    fn get_uid(&self) -> &Self::UIDType {
-    /// #        &self.id
-    /// #    }
-    /// # }
     /// #
     /// # futures::executor::block_on(async move {
     /// let client = Client::new("http://localhost:7700", "masterKey");
@@ -329,7 +329,7 @@ impl Task {
     /// # futures::executor::block_on(async move {
     /// # let client = Client::new("http://localhost:7700", "masterKey");
     /// let task = client
-    ///   .create_index("is_success", None)
+    ///   .create_index("is_pending", None)
     ///   .await
     ///   .unwrap();
     ///
@@ -384,7 +384,6 @@ mod test {
     use super::*;
     use crate::{
         client::*,
-        document,
         errors::{ErrorCode, ErrorType},
     };
     use meilisearch_test_macro::meilisearch_test;
@@ -398,14 +397,6 @@ mod test {
         kind: String,
     }
 
-    impl document::Document for Document {
-        type UIDType = usize;
-
-        fn get_uid(&self) -> &Self::UIDType {
-            &self.id
-        }
-    }
-
     #[test]
     fn test_deserialize_task() {
         let datetime = OffsetDateTime::parse(
